==> better-admin-ui-vue-0.0.1.tgz: package/es/components/Modal/Modal.js <==
import isPromise from 'is-promise';
import AModal from 'ant-design-vue/es/modal';
import { getComponentFromProp, mergeProps } from 'ant-design-vue/es/_util/props-util';
import Button from 'ant-design-vue/es/button';
import { ModalProps } from './types';
/**
 *  模态弹框，内部处理confirmLoading
 */

export default {
  name: 'EModal',
  "extends": AModal,
  components: {
    Button: Button
  },
  props: ModalProps,
  data: function data() {
    return {
      easyConfirmLoading: false
    };
  },
  methods: {
    handleOk: function handleOk(e) {
      var _this = this;

      // 判断props中是否传入了okFunc，是则调用此方法
      if (this.$props.okFunc) {
        var res = this.$props.okFunc(e);

        if (isPromise(res)) {
          this.$data.easyConfirmLoading = true;
          res.then(function () {
            _this.$data.easyConfirmLoading = false; // 成功返回自动隐藏弹框

            _this.$emit('change', false);
          })["catch"](function () {
            _this.$data.easyConfirmLoading = false;
          });
        }
      } else {
        this.$emit('ok', e);
      }
    },
    renderFooter: function renderFooter(locale) {
      var h = this.$createElement;
      var okType = this.okType;
      var confirmLoading = this.easyConfirmLoading;
      var cancelBtnProps = mergeProps({
        on: {
          click: this.handleCancel
        }
      }, this.cancelButtonProps || {});
      var okBtnProps = mergeProps({
        on: {
          click: this.handleOk
        },
        props: {
          type: okType,
          loading: confirmLoading
        }
      }, this.okButtonProps || {});
      return h('div', [h(Button, cancelBtnProps, [getComponentFromProp(this, 'cancelText') || locale.cancelText]), h(Button, okBtnProps, [getComponentFromProp(this, 'okText') || locale.okText])]);
    }
  }
};

==> better-admin-ui-vue-0.0.21.tgz: package/es/components/Modal/Modal.js <==
import isPromise from 'is-promise';
import AModal from 'ant-design-vue/es/modal';
import { getComponentFromProp, mergeProps } from 'ant-design-vue/es/_util/props-util';
import AButton from 'ant-design-vue/es/button';
import { ModalProps } from './types';
/**
 *  模态弹框，内部处理confirmLoading
 */

export default {
  name: 'EModal',
  "extends": AModal,
  props: ModalProps,
  data: function data() {
    return {
      easyConfirmLoading: false
    };
  },
  methods: {
    handleOk: function handleOk(e) {
      var _this = this;

      // 判断props中是否传入了okFunc，是则调用此方法
      if (this.$props.okFunc) {
        var res = this.$props.okFunc(e);

        if (isPromise(res)) {
          this.$data.easyConfirmLoading = true;
          res.then(function () {
            _this.$data.easyConfirmLoading = false; // 成功返回自动隐藏弹框

            _this.$emit('change', false);
          })["catch"](function () {
            _this.$data.easyConfirmLoading = false;
          });
        }
      } else {
        this.$emit('ok', e);
      }
    },
    renderFooter: function renderFooter(locale) {
      var h = this.$createElement;
      var okType = this.okType;
      var confirmLoading = this.easyConfirmLoading;
      var cancelBtnProps = mergeProps({
        on: {
          click: this.handleCancel
        }
      }, this.cancelButtonProps || {});
      var okBtnProps = mergeProps({
        on: {
          click: this.handleOk
        },
        props: {
          type: okType,
          loading: confirmLoading
        }
      }, this.okButtonProps || {});
      return h('div', [h(AButton, cancelBtnProps, [getComponentFromProp(this, 'cancelText') || locale.cancelText]), h(AButton, okBtnProps, [getComponentFromProp(this, 'okText') || locale.okText])]);
    }
  }
};
